==> alchemyjsonschema-0.2.1.1.tar.gz: alchemyjsonschema-0.2.1.1/setup.py <==
# -*- coding:utf-8 -*-

import os
import sys

from setuptools import setup, find_packages
here = os.path.abspath(os.path.dirname(__file__))
try:
    with open(os.path.join(here, 'README.rst')) as f:
        README = f.read()
    with open(os.path.join(here, 'CHANGES.txt')) as f:
        CHANGES = f.read()
except IOError:
    README = CHANGES = ''

install_requires=[
    'setuptools',
    'sqlalchemy',
    'jsonschema',
    'strict-rfc3339',
    'isodate',  # hmm.
    'pytz'
    ]

docs_extras = [
    ]

tests_require =[
    "pytest", 
    "webob"
]
testing_extras = tests_require + [
    ]

from setuptools.command.test import test as TestCommand

class PyTest(TestCommand):
    def finalize_options(self):
        TestCommand.finalize_options(self)
        self.test_args = []
        self.test_suite = True
    def run_tests(self):
        import pytest
        pytest.main(self.test_args)


setup(name='alchemyjsonschema',
      version='0.2.1.1',
      description='mappeing jsonschema for sqlalchemy models',
      long_description=README + '\n\n' +  CHANGES,
      classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: Implementation :: CPython",
        ],
      keywords='',
      author="",
      author_email="",
      url="https://github.com/podhmo/alchemyjsonschema",
      packages=find_packages(),
      include_package_data=True,
      zip_safe=False,
      install_requires = install_requires,
      extras_require = {
          'testing':testing_extras,
          'docs':docs_extras,
          },
      tests_require = tests_require,
      cmdclass = {'test': PyTest},
      entry_points = """
      [console_scripts]
      alchemyjsonschema = alchemyjsonschema.command:main
      """
      )

==> alchemyjsonschema-0.2.2.tar.gz: alchemyjsonschema-0.2.2/setup.py <==
# -*- coding:utf-8 -*-

import os

from setuptools import setup, find_packages
here = os.path.abspath(os.path.dirname(__file__))
try:
    with open(os.path.join(here, 'README.rst')) as f:
        README = f.read()
    with open(os.path.join(here, 'CHANGES.txt')) as f:
        CHANGES = f.read()
except IOError:
    README = CHANGES = ''

install_requires = [
    'sqlalchemy',
    'jsonschema',
    'strict-rfc3339',
    'isodate',  # hmm.
    'pytz'
]

docs_extras = [
]

tests_require = [
    "pytest",
    "webob"
]

testing_extras = tests_require + [
]

from setuptools.command.test import test as TestCommand


class PyTest(TestCommand):
    def finalize_options(self):
        TestCommand.finalize_options(self)
        self.test_args = []
        self.test_suite = True

    def run_tests(self):
        import pytest
        pytest.main(self.test_args)


setup(name='alchemyjsonschema',
      version='0.2.2',
      description='mapping jsonschema for sqlalchemy models',
      long_description=README + '\n\n' + CHANGES,
      classifiers=[
          "Programming Language :: Python",
          "Programming Language :: Python :: Implementation :: CPython",
      ],
      keywords='sqlalchemy jsonschema',
      author="podhmo",
      author_email="",
      url="https://github.com/podhmo/alchemyjsonschema",
      packages=find_packages(),
      include_package_data=True,
      zip_safe=False,
      install_requires=install_requires,
      extras_require={
          'testing': testing_extras,
          'docs': docs_extras,
      },
      tests_require=tests_require,
      cmdclass={'test': PyTest},
      entry_points="""
      [console_scripts]
      alchemyjsonschema=alchemyjsonschema.command:main
      """)
